local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local action = x.Action
local target = x.Target

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.EnemyDetected, "White", "Pink")
		return x.NoCC
	end,
}

--[[
  ____        _                                  _____            _     _                                           _   ____         __  __     
 |  _ \      | |                                / ____|          | |   | |                                         | | |  _ \       / _|/ _|    
 | |_) | __ _| | __ _ _ __   ___ ___   ______  | |     ___   ___ | | __| | _____      ___ __  ___    __ _ _ __   __| | | |_) |_   _| |_| |_ ___ 
 |  _ < / _` | |/ _` | '_ \ / __/ _ \ |______| | |    / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|  / _` | '_ \ / _` | |  _ <| | | |  _|  _/ __|
 | |_) | (_| | | (_| | | | | (_|  __/          | |___| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \ | (_| | | | | (_| | | |_) | |_| | | | | \__ \
 |____/ \__,_|_|\__,_|_| |_|\___\___|           \_____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/  \__,_|_| |_|\__,_| |____/ \__,_|_| |_| |___/
                                                                                                                                                
 ]]

a.spells["solar_beam"] = {
	ID = 78675--[[Solar Beam]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoRangeCheck = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["stance,choose=moonkin_form"] = {
	Type = "form",
	ID = 24858--[[Moonkin Form]],
	Buff = 24858--[[Moonkin Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["potion,name=potion_of_prolonged_power,if=buff.celestial_alignment.up|buff.incarnation.up"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and (buff.celestial_alignment.up_nogcd or buff.incarnation.up_nogcd)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["blessing_of_elune,if=active_enemies<=2&talent.blessing_of_the_ancients.enabled&buff.blessing_of_elune.down"] = {
	ID = 202360--[[Blessing of the Ancients]],
	Check = function(z)
		return x.ShouldPermanentBuff and x.ActiveEnemies <= 2 and talent.blessing_of_the_ancients.enabled and buff.blessing_of_elune.down
	end,
	FlashColor = "Green",
	Continue = true,
}

a.spells["blessing_of_elune,if=active_enemies>=3&talent.blessing_of_the_ancients.enabled&buff.blessing_of_anshe.down"] = {
	ID = 202360--[[Blessing of the Ancients]],
	Check = function(z)
		return x.ShouldPermanentBuff and x.ActiveEnemies >= 3 and talent.blessing_of_the_ancients.enabled and buff.blessing_of_anshe.down
	end,
	FlashColor = "Green",
	Continue = true,
}

a.spells["berserking,if=buff.celestial_alignment.up|buff.incarnation.up"] = {
	ID = 26297--[[Berserking]],
	Check = function(z)
		return buff.celestial_alignment.up_nogcd or buff.incarnation.up_nogcd
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

--[[
  ____        _                                 ______                         __   ______ _                  
 |  _ \      | |                               |  ____|                       / _| |  ____| |                 
 | |_) | __ _| | __ _ _ __   ___ ___   ______  | |__ _   _ _ __ _   _    ___ | |_  | |__  | |_   _ _ __   ___ 
 |  _ < / _` | |/ _` | '_ \ / __/ _ \ |______| |  __| | | | '__| | | |  / _ \|  _| |  __| | | | | | '_ \ / _ \
 | |_) | (_| | | (_| | | | | (_|  __/          | |  | |_| | |  | |_| | | (_) | |   | |____| | |_| | | | |  __/
 |____/ \__,_|_|\__,_|_| |_|\___\___|          |_|   \__,_|_|   \__, |  \___/|_|   |______|_|\__,_|_| |_|\___|
                                                                 __/ |                                        
                                                                |___/                                         
]]

a.spells["incarnation,if=astral_power>=95&cooldown.fury_of_elune.remains<=gcd"] = {
	ID = 102560--[[Incarnation: Chosen of Elune]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.AstralPower >= 95 and cooldown.fury_of_elune.remains_nogcd <= x.MaxGCD
	end,
}

a.spells["force_of_nature,if=!buff.fury_of_elune.up"] = {
	ID = 205636--[[Force of Nature]],
	Check = function(z)
		return talent.force_of_nature.enabled and not buff.fury_of_elune.up
	end,
}

a.spells["fury_of_elune,if=astral_power>=95"] = {
	ID = 202770--[[Fury of Elune]],
	Check = function(z)
		return talent.fury_of_elune.enabled and x.AstralPower >= 95
	end,
}

a.spells["new_moon,if=((charges=2&recharge_time<5)|charges=3)&&(buff.fury_of_elune.up|(cooldown.fury_of_elune.remains>gcd*3&astral_power<=90))"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return ((x.MoonCharges == 2 and cooldown.new_moon.remains < 5) or x.MoonCharges == 3) and (buff.fury_of_elune.up or (cooldown.fury_of_elune.remains > x.MaxGCD * 3 and x.AstralPower <= 90))
	end,
}

a.spells["half_moon,if=((charges=2&recharge_time<5)|charges=3)&&(buff.fury_of_elune.up|(cooldown.fury_of_elune.remains>gcd*3&astral_power<=80))"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return ((x.MoonCharges == 2 and cooldown.half_moon.remains < 5) or x.MoonCharges == 3) and (buff.fury_of_elune.up or (cooldown.fury_of_elune.remains > x.MaxGCD * 3 and x.AstralPower <= 80))
	end,
}

a.spells["full_moon,if=((charges=2&recharge_time<5)|charges=3)&&(buff.fury_of_elune.up|(cooldown.fury_of_elune.remains>gcd*3&astral_power<=60))"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return ((x.MoonCharges == 2 and cooldown.full_moon.remains < 5) or x.MoonCharges == 3) and (buff.fury_of_elune.up or (cooldown.fury_of_elune.remains > x.MaxGCD * 3 and x.AstralPower <= 60))
	end,
}

a.spells["astral_communion,if=buff.fury_of_elune.up&astral_power<=25"] = {
	ID = 202359--[[Astral Communion]],
	Check = function(z)
		return buff.fury_of_elune.up_nogcd and x.AstralPower <= 25
	end,
	FlashColor = "Yellow",
	Continue = true,
	NoGCD = true,
}

a.spells["warrior_of_elune,if=buff.fury_of_elune.up|(cooldown.fury_of_elune.remains>=35&buff.lunar_empowerment.up)"] = {
	ID = 202425--[[Warrior of Elune]],
	Check = function(z)
		return talent.warrior_of_elune.enabled and (buff.fury_of_elune.up_nogcd or (cooldown.fury_of_elune.remains_nogcd >= 35 and buff.lunar_empowerment.up_nogcd))
	end,
	FlashColor = "Yellow",
	Continue = true,
	NoGCD = true,
}

a.spells["lunar_strike,if=buff.warrior_of_elune.up&(astral_power<=90|(astral_power<=85&buff.incarnation.up))"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.warrior_of_elune.up and (x.AstralPower <= 90 or (x.AstralPower <= 85 and buff.incarnation.up))
	end,
}

a.spells["new_moon,if=astral_power<=90&buff.fury_of_elune.up"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPower <= 90 and buff.fury_of_elune.up
	end,
}

a.spells["half_moon,if=astral_power<=80&buff.fury_of_elune.up&astral_power>cast_time*12"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPower <= 80 and buff.fury_of_elune.up and x.AstralPower > action.half_moon.cast_time * 12
	end,
}

a.spells["full_moon,if=astral_power<=60&buff.fury_of_elune.up&astral_power>cast_time*12"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPower <= 60 and buff.fury_of_elune.up and x.AstralPower > action.full_moon.cast_time * 12
	end,
}

a.spells["moonfire,if=buff.fury_of_elune.down&remains<=6.6"] = {
	ID = 8921--[[Moonfire]],
	Check = function(z)
		return buff.fury_of_elune.down and dot.moonfire.remains <= 6.6
	end,
}

a.spells["sunfire,if=buff.fury_of_elune.down&remains<5.4"] = {
	ID = 93402--[[Sunfire]],
	Check = function(z)
		return buff.fury_of_elune.down and dot.sunfire.remains < 5.4
	end,
}

a.spells["stellar_flare,if=remains<7.2&active_enemies=1"] = {
	ID = 202347--[[Stellar Flare]],
	Check = function(z)
		return talent.stellar_flare.enabled and dot.stellar_flare.remains < 7.2 and x.ActiveEnemies == 1
	end,
}

a.spells["starfall,if=(active_enemies>=2&talent.stellar_flare.enabled|active_enemies>=3)&buff.fury_of_elune.down&cooldown.fury_of_elune.remains>10"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return x.AstralPower >= x.StarfallCost and ((x.ActiveEnemies >= 2 and talent.stellar_flare.enabled or x.ActiveEnemies >= 3) and buff.fury_of_elune.down and cooldown.fury_of_elune.remains > 10)
	end,
}

a.spells["starsurge,if=active_enemies<=2&buff.fury_of_elune.down&cooldown.fury_of_elune.remains>7"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.AstralPower >= x.StarsurgeCost and x.ActiveEnemies <= 2 and buff.fury_of_elune.down and cooldown.fury_of_elune.remains > 7
	end,
}

a.spells["starsurge,if=buff.fury_of_elune.down&((astral_power>=92&cooldown.fury_of_elune.remains>gcd*3)|(cooldown.warrior_of_elune.remains<=5&cooldown.fury_of_elune.remains>=35&buff.lunar_empowerment.stack<2))"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.AstralPower >= x.StarsurgeCost and buff.fury_of_elune.down and ((x.AstralPower >= 92 and cooldown.fury_of_elune.remains > x.MaxGCD * 3) or (cooldown.warrior_of_elune.remains <= 5 and cooldown.fury_of_elune.remains >= 35 and buff.lunar_empowerment.stack < 2))
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.stack=3|(buff.lunar_empowerment.remains<5&buff.lunar_empowerment.up)|active_enemies>=2"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.lunar_empowerment.stack == 3 or (buff.lunar_empowerment.remains < 5 and buff.lunar_empowerment.up) or x.ActiveEnemies >= 2
	end,
}

--[[
  ____        _                                 ______                          _     _   _____                                     _       _               
 |  _ \      | |                               |  ____|                        | |   | | |  __ \                                   | |     | |              
 | |_) | __ _| | __ _ _ __   ___ ___   ______  | |__   _ __ ___   ___ _ __ __ _| | __| | | |  | |_ __ ___  __ _ _ __ ___   ___ __ _| |_ ___| |__   ___ _ __ 
 |  _ < / _` | |/ _` | '_ \ / __/ _ \ |______| |  __| | '_ ` _ \ / _ \ '__/ _` | |/ _` | | |  | | '__/ _ \/ _` | '_ ` _ \ / __/ _` | __/ __| '_ \ / _ \ '__|
 | |_) | (_| | | (_| | | | | (_|  __/          | |____| | | | | |  __/ | | (_| | | (_| | | |__| | | |  __/ (_| | | | | | | (_| (_| | || (__| | | |  __/ |   
 |____/ \__,_|_|\__,_|_| |_|\___\___|          |______|_| |_| |_|\___|_|  \__,_|_|\__,_| |_____/|_|  \___|\__,_|_| |_| |_|\___\__,_|\__\___|_| |_|\___|_|   
                                                                                                                                                            
 ]]

a.spells["astral_communion,if=astral_power.deficit>=75&buff.the_emerald_dreamcatcher.up"] = {
	ID = 202359--[[Astral Communion]],
	Check = function(z)
		return x.AstralPowerDeficit >= 75 and buff.the_emerald_dreamcatcher.up_nogcd
	end,
	FlashColor = "Yellow",
	Continue = true,
	NoGCD = true,
}

a.spells["incarnation,if=astral_power>=60|buff.bloodlust.up"] = {
	ID = 102560--[[Incarnation: Chosen of Elune]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return talent.incarnation.enabled and x.AstralPower >= 60
	end,
}

a.spells["celestial_alignment,if=astral_power>=60&!buff.the_emerald_dreamcatcher.up"] = {
	ID = 194223--[[Celestial Alignment]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.AstralPower >= 60 and not buff.the_emerald_dreamcatcher.up_nogcd
	end,
}

a.spells["starsurge,if=(gcd.max*astral_power/26)>target.time_to_die"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.AstralPower >= x.StarsurgeCost and (x.MaxGCD * x.AstralPower / 26) > target.time_to_die
	end,
}

a.spells["stellar_flare,cycle_targets=1,max_cycle_targets=4,if=active_enemies<4&remains<7.2"] = {
	ID = 202347--[[Stellar Flare]],
	Check = function(z)
		return talent.stellar_flare.enabled and x.ActiveEnemies < 4 and dot.stellar_flare.remains < 7.2
	end,
}

a.spells["moonfire,if=((talent.natures_balance.enabled&remains<3)|(remains<6.6&!talent.natures_balance.enabled))&(buff.the_emerald_dreamcatcher.remains>gcd.max|!buff.the_emerald_dreamcatcher.up)"] = {
	ID = 8921--[[Moonfire]],
	Check = function(z)
		return ((talent.natures_balance.enabled and dot.moonfire.remains < 3) or (dot.moonfire.remains < 6.6 and not talent.natures_balance.enabled)) and (buff.the_emerald_dreamcatcher.remains > x.MaxGCD or not buff.the_emerald_dreamcatcher.up)
	end,
}

a.spells["sunfire,if=((talent.natures_balance.enabled&remains<3)|(remains<5.4&!talent.natures_balance.enabled))&(buff.the_emerald_dreamcatcher.remains>gcd.max|!buff.the_emerald_dreamcatcher.up)"] = {
	ID = 93402--[[Sunfire]],
	Check = function(z)
		return ((talent.natures_balance.enabled and dot.sunfire.remains < 3) or (dot.sunfire.remains < 5.4 and not talent.natures_balance.enabled)) and (buff.the_emerald_dreamcatcher.remains > x.MaxGCD or not buff.the_emerald_dreamcatcher.up)
	end,
}

a.spells["force_of_nature,if=buff.the_emerald_dreamcatcher.remains>execute_time"] = {
	ID = 205636--[[Force of Nature]],
	Check = function(z)
		return talent.force_of_nature.enabled and buff.the_emerald_dreamcatcher.remains > action.force_of_nature.execute_time
	end,
}

a.spells["starfall,if=buff.oneths_overconfidence.react&buff.the_emerald_dreamcatcher.remains>execute_time"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return buff.oneths_overconfidence.up and buff.the_emerald_dreamcatcher.remains > action.starfall.execute_time
	end,
}

a.spells["new_moon,if=astral_power.deficit>=10&buff.the_emerald_dreamcatcher.remains>execute_time&astral_power>=16"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit >= 10 and buff.the_emerald_dreamcatcher.remains > action.new_moon.execute_time and x.AstralPower >= 16
	end,
}

a.spells["half_moon,if=astral_power.deficit>=20&buff.the_emerald_dreamcatcher.remains>execute_time&astral_power>=6"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit >= 20 and buff.the_emerald_dreamcatcher.remains > action.half_moon.execute_time and x.AstralPower>=6
	end,
}

a.spells["full_moon,if=astral_power.deficit>=40&buff.the_emerald_dreamcatcher.remains>execute_time"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit >= 40 and buff.the_emerald_dreamcatcher.remains > action.full_moon.execute_time
	end,
}

a.spells["lunar_strike,if=(buff.lunar_empowerment.up&buff.the_emerald_dreamcatcher.remains>execute_time&(!(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=15|(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=22.5))&spell_haste<0.4"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return (buff.lunar_empowerment.up and buff.the_emerald_dreamcatcher.remains > action.lunar_strike.execute_time and (not (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 15 or (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 22.5)) and UnitSpellHaste("player") / 100 < 0.4
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.stack>1&buff.the_emerald_dreamcatcher.remains>2*execute_time&astral_power>=6&(dot.moonfire.remains>5|(dot.sunfire.remains<5.4&dot.moonfire.remains>6.6))&(!(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=10|(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=15)"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return buff.solar_empowerment.stack > 1 and buff.the_emerald_dreamcatcher.remains > 2 * action.solar_wrath.execute_time and x.AstralPower >= 6 and (dot.moonfire.remains > 5 or (dot.sunfire.remains < 5.4 and dot.moonfire.remains > 6.6)) and (not (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 10 or (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 15)
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.up&buff.the_emerald_dreamcatcher.remains>execute_time&astral_power>=11&(!(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=15|(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=22.5)"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.lunar_empowerment.up and buff.the_emerald_dreamcatcher.remains > action.lunar_strike.execute_time and x.AstralPower >= 11 and (not (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 15 or (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 22.5)
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.up&buff.the_emerald_dreamcatcher.remains>execute_time&astral_power>=16&(!(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=10|(buff.celestial_alignment.up|buff.incarnation.up)&astral_power.deficit>=15)"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return buff.solar_empowerment.up and buff.the_emerald_dreamcatcher.remains > action.solar_wrath.execute_time and x.AstralPower >= 16 and (not (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 10 or (buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPowerDeficit >= 15)
	end,
}

a.spells["starsurge,if=(buff.the_emerald_dreamcatcher.up&buff.the_emerald_dreamcatcher.remains<gcd.max)|astral_power>85|((buff.celestial_alignment.up|buff.incarnation.up)&astral_power>30)"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.AstralPower >= x.StarsurgeCost and ((buff.the_emerald_dreamcatcher.up and buff.the_emerald_dreamcatcher.remains < x.MaxGCD) or x.AstralPower > 85 or ((buff.celestial_alignment.up or buff.incarnation.up) and x.AstralPower > 30))
	end,
}

a.spells["starfall,if=buff.oneths_overconfidence.up"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return buff.oneths_overconfidence.up
	end,
}

a.spells["new_moon,if=astral_power.deficit>=10"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.EnemyDetected and x.AstralPowerDeficit >= 10
	end,
}

a.spells["half_moon,if=astral_power.deficit>=20"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.EnemyDetected and x.AstralPowerDeficit >= 20
	end,
}

a.spells["full_moon,if=astral_power.deficit>=40"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.EnemyDetected and x.AstralPowerDeficit >= 40
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.up"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return buff.solar_empowerment.up
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.up"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.lunar_empowerment.up
	end,
}

a.spells["solar_wrath"] = {
	ID = 190984--[[Solar Wrath]],
}

--[[
  ____        _                                               ______ 
 |  _ \      | |                                   /\        |  ____|
 | |_) | __ _| | __ _ _ __   ___ ___   ______     /  \   ___ | |__   
 |  _ < / _` | |/ _` | '_ \ / __/ _ \ |______|   / /\ \ / _ \|  __|  
 | |_) | (_| | | (_| | | | | (_|  __/           / ____ \ (_) | |____ 
 |____/ \__,_|_|\__,_|_| |_|\___\___|          /_/    \_\___/|______|
                                                                     
]]

a.spells["astral_communion,if=astral_power.deficit>=79"] = {
	ID = 202359--[[Astral Communion]],
	Check = function(z)
		return x.AstralPowerDeficit >= 79
	end,
	FlashColor = "Yellow",
	Continue = true,
	NoGCD = true,
}

a.spells["warrior_of_elune"] = {
	ID = 202425--[[Warrior of Elune]],
	Check = function(z)
		return talent.warrior_of_elune.enabled
	end,
	FlashColor = "Yellow",
	Continue = true,
	NoGCD = true,
}

a.spells["incarnation,if=astral_power>=40"] = {
	ID = 102560--[[Incarnation: Chosen of Elune]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return talent.incarnation.enabled and x.AstralPower >= 40
	end,
}

a.spells["celestial_alignment,if=astral_power>=40"] = {
	ID = 194223--[[Celestial Alignment]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.AstralPower >= 40
	end,
}

a.spells["starfall,if=debuff.stellar_empowerment.remains<gcd.max*2|astral_power.deficit<22.5|(buff.celestial_alignment.remains>8|buff.incarnation.remains>8)|target.time_to_die<8"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return x.AstralPower >= x.StarfallCost and (debuff.stellar_empowerment.remains < x.MaxGCD * 2 or x.AstralPowerDeficit < 22.5 or (buff.celestial_alignment.remains > 8 or buff.incarnation.remains > 8) or target.time_to_die < 8)
	end,
}

a.spells["stellar_flare,target_if=refreshable,if=target.time_to_die>10"] = {
	ID = 202347--[[Stellar Flare]],
	Check = function(z)
		return talent.stellar_flare.enabled and  dot.stellar_flare.remains <= 7.2 and target.time_to_die > 10
	end,
}

a.spells["sunfire,target_if=refreshable,if=astral_power.deficit>7&target.time_to_die>4"] = {
	ID = 93402--[[Sunfire]],
	Check = function(z)
		return dot.sunfire.refreshable and x.AstralPowerDeficit > 7 and target.time_to_die > 4
	end,
}

a.spells["moonfire,target_if=refreshable,if=astral_power.deficit>7&target.time_to_die>4"] = {
	ID = 8921--[[Moonfire]],
	Check = function(z)
		return dot.moonfire.refreshable and x.AstralPowerDeficit > 7 and target.time_to_die > 4
	end,
}

a.spells["force_of_nature"] = {
	ID = 205636--[[Force of Nature]],
	Check = function(z)
		return talent.force_of_nature.enabled
	end,
}

a.spells["starsurge,if=buff.oneths_intuition.react&(!buff.astral_acceleration.up|buff.astral_acceleration.remains>5|astral_power.deficit<44)"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return buff.oneths_intuition.up and (not buff.astral_acceleration.up or buff.astral_acceleration.remains > 5 or x.AstralPowerDeficit < 44)
	end,
}

a.spells["new_moon,if=astral_power.deficit>14&(!(buff.celestial_alignment.up|buff.incarnation.up)|(charges=2&recharge_time<5)|charges=3)"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 14 and (not (buff.celestial_alignment.up or buff.incarnation.up) or (x.MoonCharges == 2 and cooldown.new_moon.remains < 5) or x.MoonCharges == 3)
	end,
}

a.spells["half_moon,if=astral_power.deficit>24"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 24
	end,
}

a.spells["full_moon,if=astral_power.deficit>44"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 44
	end,
}

a.spells["lunar_strike,if=buff.warrior_of_elune.up"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.warrior_of_elune.up
	end,
}

a.spells["lunar_strike,if=spell_targets.lunar_strike>=4|spell_haste<0.45"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return x.ActiveEnemies >= 4 or UnitSpellHaste("player") / 100 < 0.45
	end,
}

--[[
  ____        _                                  _____ _             _        _______                   _   
 |  _ \      | |                                / ____(_)           | |      |__   __|                 | |  
 | |_) | __ _| | __ _ _ __   ___ ___   ______  | (___  _ _ __   __ _| | ___     | | __ _ _ __ __ _  ___| |_ 
 |  _ < / _` | |/ _` | '_ \ / __/ _ \ |______|  \___ \| | '_ \ / _` | |/ _ \    | |/ _` | '__/ _` |/ _ \ __|
 | |_) | (_| | | (_| | | | | (_|  __/           ____) | | | | | (_| | |  __/    | | (_| | | | (_| |  __/ |_ 
 |____/ \__,_|_|\__,_|_| |_|\___\___|          |_____/|_|_| |_|\__, |_|\___|    |_|\__,_|_|  \__, |\___|\__|
                                                                __/ |                         __/ |         
                                                               |___/                         |___/          
]]
a.spells["moonfire,target_if=refreshable,if=((talent.natures_balance.enabled&remains<3)|remains<6.6)&astral_power.deficit>7&target.time_to_die>8"] = {
	ID = 8921--[[Moonfire]],
	Check = function(z)
		return dot.moonfire.refreshable and (((talent.natures_balance.enabled and dot.moonfire.remains < 3) or dot.moonfire.remains < 6.6) and x.AstralPowerDeficit > 7 and target.time_to_die > 8)
	end,
}

a.spells["sunfire,target_if=refreshable,if=((talent.natures_balance.enabled&remains<3)|remains<5.4)&astral_power.deficit>7&target.time_to_die>8"] = {
	ID = 93402--[[Sunfire]],
	Check = function(z)
		return dot.sunfire.refreshable and (((talent.natures_balance.enabled and dot.sunfire.remains < 3) or dot.sunfire.remains < 5.4) and x.AstralPowerDeficit > 7 and target.time_to_die > 8)
	end,
}

a.spells["starsurge,if=buff.oneths_intuition.react"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return buff.oneths_intuition.up
	end,
}

a.spells["starfall,if=(buff.oneths_overconfidence.react&(!buff.astral_acceleration.up|buff.astral_acceleration.remains>5|astral_power.deficit<40))|(variable.starfall_st&!debuff.stellar_empowerment.up)"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return x.AstralPower >= x.StarfallCost and ((buff.oneths_overconfidence.up and (not buff.astral_acceleration.up or buff.astral_acceleration.remains > 5 or x.AstralPowerDeficit < 40)) or (talent.soul_of_the_forest.enabled and set_bonus.tier21_4pc and not debuff.stellar_empowerment.up))
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.stack=3&astral_power.deficit>10"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return buff.solar_empowerment.stack == 3 and x.AstralPowerDeficit > 10
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.stack=3&astral_power.deficit>15"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.lunar_empowerment.stack == 3 and x.AstralPowerDeficit > 15
	end,
}

a.spells["starsurge,if=astral_power.deficit<40|(buff.celestial_alignment.up|buff.incarnation.up|buff.astral_acceleration.remains>5|(set_bonus.tier21_4pc&!buff.solar_solstice.up))|(gcd.max*(astral_power/40))>target.time_to_die"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.AstralPower >= x.StarsurgeCost and (x.AstralPowerDeficit < 40 or (buff.celestial_alignment.up or buff.incarnation.up or buff.astral_acceleration.remains > 5 or (set_bonus.tier21_4pc and not buff.solar_solstice.up)) or (x.MaxGCD * (x.AstralPower / 40)) > target.time_to_die)
	end,
}

a.spells["new_moon,if=astral_power.deficit>10&(!(buff.celestial_alignment.up|buff.incarnation.up)|(charges=2&recharge_time<5)|charges=3)"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 10 and (not (buff.celestial_alignment.up or buff.incarnation.up) or (x.MoonCharges == 2 and cooldown.new_moon.remains < 5) or x.MoonCharges == 3)
	end,
}

a.spells["half_moon,if=astral_power.deficit>20&(!(buff.celestial_alignment.up|buff.incarnation.up)|(charges=2&recharge_time<5)|charges=3)"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 20 and (not (buff.celestial_alignment.up or buff.incarnation.up) or (x.MoonCharges == 2 and cooldown.half_moon.remains < 5) or x.MoonCharges == 3)
	end,
}

a.spells["full_moon,if=astral_power.deficit>40"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.MoonCharges >= 1 and x.AstralPowerDeficit > 40
	end,
}

a.spells["lunar_strike,if=buff.warrior_of_elune.up&buff.lunar_empowerment.up"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return buff.warrior_of_elune.up and buff.lunar_empowerment.up
	end,
}
