local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local action = x.Action
local target = x.Target

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

--[[
   _____                     _ _             
  / ____|                   | (_)            
 | |  __ _   _  __ _ _ __ __| |_  __ _ _ __  
 | | |_ | | | |/ _` | '__/ _` | |/ _` | '_ \ 
 | |__| | |_| | (_| | | | (_| | | (_| | | | |
  \_____|\__,_|\__,_|_|  \__,_|_|\__,_|_| |_|
                                             
                                             
]]

a.spells["stance,choose=bear_form"] = {
	Type = "form",
	ID = 5487--[[Bear Form]],
	Buff = 5487--[[Bear Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Wild Charge"] = {
	ID = 16979--[[Wild Charge]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["skull_bash"] = {
	ID = 106839--[[Skull Bash]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Growl"] = {
	ID = 6795--[[Growl]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.EnemyDetected and s.UnitInfo("target") ~= "player" and x.InstanceType ~= "pvp"
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["rage_of_the_sleeper"] = {
	ID = 200851--[[Rage of the Sleeper]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["lunar_beam"] = {
	ID = 204066--[[Lunar Beam]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff
	end,
	NoGCD = true,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["incarnation"] = {
	ID = 102558--[[Incarnation: Guardian of Ursoc]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["frenzied_regeneration,if=incoming_damage_5s%health.max>=0.5|health<=health.max*0.4"] = {
	ID = 22842--[[Frenzied Regeneration]],
	Buff = 22842--[[Frenzied Regeneration]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.Rage >= 10 and (s.IncomingDamage(5000) / x.MaxHealth >= 0.5 or x.Health <= x.MaxHealth * 0.4)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = false,
}

a.spells["bristling_fur,if=buff.ironfur.stack=1|buff.ironfur.down"] = {
	ID = 155835--[[Bristling Fur]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and (buff.ironfur.stack_nogcd == 1 or buff.ironfur.down_nogcd)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["ironfur,if=(buff.ironfur.up=0)|(buff.gory_fur.up=1)|(rage>=80)"] = {
	ID = 192081--[[Ironfur]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and ((buff.ironfur.down_nogcd and x.Rage >= 45) or (buff.gory_fur.up_nogcd and x.Rage >= 33) or x.Rage >= 80)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["moonfire,if=buff.incarnation.up=1&dot.moonfire.remains<=4.8"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and buff.incarnation.up
	end,
}

a.spells["thrash_bear,if=buff.incarnation.up=1&dot.thrash.remains<=4.5"] = {
	ID = 77758--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and buff.incarnation.up and dot.thrash.remains <= 4.5 and s.MeleeDistance() then
			s.Flash("Thrash")
			x.Stop = true
			return true
		else
			x.Stop = false
			return false
		end
	end,
}

a.spells["pulverize,if=buff.pulverize.up=0|buff.pulverize.remains<=6"] = {
	ID = 80313--[[Pulverize]],
	Check = function(z)
		return x.EnemyDetected and not x.Stop and (buff.pulverize.down or buff.pulverize.remains <= 6)
	end,
}

a.spells["mangle"] = {
	ID = 33917--[[Mangle]],
	Check = function(z)
		return x.EnemyDetected and not x.Stop
	end,
}

a.spells["thrash_bear"] = {
	ID = 77758--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and s.MeleeDistance() then
			s.Flash("Thrash")
			x.Stop = true
			return true
		else
			x.Stop = false
			return false
		end
	end,
}

a.spells["moonfire,if=buff.galactic_guardian.up=1&(!ticking|dot.moonfire.remains<=4.8)"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and buff.galactic_guardian.up and not x.Stop
	end,
}

a.spells["moonfire,if=buff.galactic_guardian.up=1"] = {
	ID = 8921--[[Moonfire]],
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and buff.galactic_guardian.up and not x.Stop
	end,
}

a.spells["moonfire,if=dot.moonfire.remains<=4.8"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and not x.Stop
	end,
}

a.spells["swipe_bear"] = {
	ID = 213764--[[Swipe]],
	NoPowerCheck = true,
	NoRangeCheck = true,
	EnemyTargetNeeded = false,
	Check = function(z)
		return x.EnemyDetected and not x.Stop and s.MeleeDistance()
	end,
}
